package com.facebook.react.uimanager;

import java.util.Arrays;
import java.util.HashSet;

public class ViewProps {
    public static final String ACCESSIBILITY_ACTIONS = "accessibilityActions";
    public static final String ACCESSIBILITY_COLLECTION = "accessibilityCollection";
    public static final String ACCESSIBILITY_COLLECTION_ITEM = "accessibilityCollectionItem";
    public static final String ACCESSIBILITY_HINT = "accessibilityHint";
    public static final String ACCESSIBILITY_LABEL = "accessibilityLabel";
    public static final String ACCESSIBILITY_LABELLED_BY = "accessibilityLabelledBy";
    public static final String ACCESSIBILITY_LIVE_REGION = "accessibilityLiveRegion";
    public static final String ACCESSIBILITY_ROLE = "accessibilityRole";
    public static final String ACCESSIBILITY_STATE = "accessibilityState";
    public static final String ACCESSIBILITY_VALUE = "accessibilityValue";
    public static final String ADJUSTS_FONT_SIZE_TO_FIT = "adjustsFontSizeToFit";
    public static final String ALIGN_CONTENT = "alignContent";
    public static final String ALIGN_ITEMS = "alignItems";
    public static final String ALIGN_SELF = "alignSelf";
    public static final String ALLOW_FONT_SCALING = "allowFontScaling";
    public static final String ASPECT_RATIO = "aspectRatio";
    public static final String AUTO = "auto";
    public static final String BACKGROUND_COLOR = "backgroundColor";
    public static final String BORDER_BOTTOM_COLOR = "borderBottomColor";
    public static final String BORDER_BOTTOM_END_RADIUS = "borderBottomEndRadius";
    public static final String BORDER_BOTTOM_LEFT_RADIUS = "borderBottomLeftRadius";
    public static final String BORDER_BOTTOM_RIGHT_RADIUS = "borderBottomRightRadius";
    public static final String BORDER_BOTTOM_START_RADIUS = "borderBottomStartRadius";
    public static final String BORDER_BOTTOM_WIDTH = "borderBottomWidth";
    public static final String BORDER_COLOR = "borderColor";
    public static final String BORDER_END_COLOR = "borderEndColor";
    public static final String BORDER_END_WIDTH = "borderEndWidth";
    public static final String BORDER_LEFT_COLOR = "borderLeftColor";
    public static final String BORDER_LEFT_WIDTH = "borderLeftWidth";
    public static final String BORDER_RADIUS = "borderRadius";
    public static final String BORDER_RIGHT_COLOR = "borderRightColor";
    public static final String BORDER_RIGHT_WIDTH = "borderRightWidth";
    public static final int[] BORDER_SPACING_TYPES = {8, 4, 5, 1, 3, 0, 2};
    public static final String BORDER_START_COLOR = "borderStartColor";
    public static final String BORDER_START_WIDTH = "borderStartWidth";
    public static final String BORDER_TOP_COLOR = "borderTopColor";
    public static final String BORDER_TOP_END_RADIUS = "borderTopEndRadius";
    public static final String BORDER_TOP_LEFT_RADIUS = "borderTopLeftRadius";
    public static final String BORDER_TOP_RIGHT_RADIUS = "borderTopRightRadius";
    public static final String BORDER_TOP_START_RADIUS = "borderTopStartRadius";
    public static final String BORDER_TOP_WIDTH = "borderTopWidth";
    public static final String BORDER_WIDTH = "borderWidth";
    public static final String BOTTOM = "bottom";
    public static final String BOX_NONE = "box-none";
    public static final String COLLAPSABLE = "collapsable";
    public static final String COLOR = "color";
    public static final String DISPLAY = "display";
    public static final String ELEVATION = "elevation";
    public static final String ELLIPSIZE_MODE = "ellipsizeMode";
    public static final String ENABLED = "enabled";
    public static final String END = "end";
    public static final String FLEX = "flex";
    public static final String FLEX_BASIS = "flexBasis";
    public static final String FLEX_DIRECTION = "flexDirection";
    public static final String FLEX_GROW = "flexGrow";
    public static final String FLEX_SHRINK = "flexShrink";
    public static final String FLEX_WRAP = "flexWrap";
    public static final String FONT_FAMILY = "fontFamily";
    public static final String FONT_SIZE = "fontSize";
    public static final String FONT_STYLE = "fontStyle";
    public static final String FONT_VARIANT = "fontVariant";
    public static final String FONT_WEIGHT = "fontWeight";
    public static final String FOREGROUND_COLOR = "foregroundColor";
    public static final String HEIGHT = "height";
    public static final String HIDDEN = "hidden";
    public static final String IMPORTANT_FOR_ACCESSIBILITY = "importantForAccessibility";
    public static final String INCLUDE_FONT_PADDING = "includeFontPadding";
    public static final String IS_ATTACHMENT = "isAttachment";
    public static final String JUSTIFY_CONTENT = "justifyContent";
    public static final String LAYOUT_DIRECTION = "layoutDirection";
    private static final HashSet<String> LAYOUT_ONLY_PROPS = new HashSet<>(Arrays.asList(new String[]{ALIGN_SELF, ALIGN_ITEMS, COLLAPSABLE, FLEX, FLEX_BASIS, FLEX_DIRECTION, FLEX_GROW, FLEX_SHRINK, FLEX_WRAP, JUSTIFY_CONTENT, ALIGN_CONTENT, DISPLAY, POSITION, "right", TOP, BOTTOM, "left", "start", "end", "width", "height", MIN_WIDTH, MAX_WIDTH, MIN_HEIGHT, MAX_HEIGHT, MARGIN, MARGIN_VERTICAL, MARGIN_HORIZONTAL, MARGIN_LEFT, MARGIN_RIGHT, MARGIN_TOP, MARGIN_BOTTOM, MARGIN_START, MARGIN_END, PADDING, PADDING_VERTICAL, PADDING_HORIZONTAL, PADDING_LEFT, PADDING_RIGHT, PADDING_TOP, PADDING_BOTTOM, PADDING_START, PADDING_END}));
    public static final String LEFT = "left";
    public static final String LETTER_SPACING = "letterSpacing";
    public static final String LINE_HEIGHT = "lineHeight";
    public static final String MARGIN = "margin";
    public static final String MARGIN_BOTTOM = "marginBottom";
    public static final String MARGIN_END = "marginEnd";
    public static final String MARGIN_HORIZONTAL = "marginHorizontal";
    public static final String MARGIN_LEFT = "marginLeft";
    public static final String MARGIN_RIGHT = "marginRight";
    public static final String MARGIN_START = "marginStart";
    public static final String MARGIN_TOP = "marginTop";
    public static final String MARGIN_VERTICAL = "marginVertical";
    public static final String MAX_FONT_SIZE_MULTIPLIER = "maxFontSizeMultiplier";
    public static final String MAX_HEIGHT = "maxHeight";
    public static final String MAX_WIDTH = "maxWidth";
    public static final String MINIMUM_FONT_SCALE = "minimumFontScale";
    public static final String MIN_HEIGHT = "minHeight";
    public static final String MIN_WIDTH = "minWidth";
    public static final String NATIVE_ID = "nativeID";
    public static final String NEEDS_OFFSCREEN_ALPHA_COMPOSITING = "needsOffscreenAlphaCompositing";
    public static final String NONE = "none";
    public static final String NUMBER_OF_LINES = "numberOfLines";
    public static final String ON = "on";
    public static final String ON_LAYOUT = "onLayout";
    public static final String OPACITY = "opacity";
    public static final String OVERFLOW = "overflow";
    public static final String PADDING = "padding";
    public static final String PADDING_BOTTOM = "paddingBottom";
    public static final String PADDING_END = "paddingEnd";
    public static final String PADDING_HORIZONTAL = "paddingHorizontal";
    public static final String PADDING_LEFT = "paddingLeft";
    public static final int[] PADDING_MARGIN_SPACING_TYPES = {8, 7, 6, 4, 5, 1, 3, 0, 2};
    public static final String PADDING_RIGHT = "paddingRight";
    public static final String PADDING_START = "paddingStart";
    public static final String PADDING_TOP = "paddingTop";
    public static final String PADDING_VERTICAL = "paddingVertical";
    public static final String POINTER_EVENTS = "pointerEvents";
    public static final String POSITION = "position";
    public static final int[] POSITION_SPACING_TYPES = {4, 5, 1, 3};
    public static final String RENDER_TO_HARDWARE_TEXTURE = "renderToHardwareTextureAndroid";
    public static final String RESIZE_METHOD = "resizeMethod";
    public static final String RESIZE_MODE = "resizeMode";
    public static final String RIGHT = "right";
    public static final String ROTATION = "rotation";
    public static final String SCALE_X = "scaleX";
    public static final String SCALE_Y = "scaleY";
    public static final String SCROLL = "scroll";
    public static final String SHADOW_COLOR = "shadowColor";
    public static final String START = "start";
    public static final String TEST_ID = "testID";
    public static final String TEXT_ALIGN = "textAlign";
    public static final String TEXT_ALIGN_VERTICAL = "textAlignVertical";
    public static final String TEXT_BREAK_STRATEGY = "textBreakStrategy";
    public static final String TEXT_DECORATION_LINE = "textDecorationLine";
    public static final String TOP = "top";
    public static final String TRANSFORM = "transform";
    public static final String TRANSLATE_X = "translateX";
    public static final String TRANSLATE_Y = "translateY";
    public static final String VIEW_CLASS_NAME = "RCTView";
    public static final String VISIBLE = "visible";
    public static final String WIDTH = "width";
    public static final String Z_INDEX = "zIndex";

    /* JADX WARNING: Can't fix incorrect switch cases order */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public static boolean isLayoutOnly(com.facebook.react.bridge.ReadableMap r19, java.lang.String r20) {
        /*
            r0 = r19
            r1 = r20
            java.util.HashSet<java.lang.String> r2 = LAYOUT_ONLY_PROPS
            boolean r2 = r2.contains(r1)
            r3 = 1
            if (r2 == 0) goto L_0x000e
            return r3
        L_0x000e:
            java.lang.String r2 = "pointerEvents"
            boolean r2 = r2.equals(r1)
            r4 = 0
            if (r2 == 0) goto L_0x002e
            java.lang.String r0 = r19.getString(r20)
            java.lang.String r1 = "auto"
            boolean r1 = r1.equals(r0)
            if (r1 != 0) goto L_0x002d
            java.lang.String r1 = "box-none"
            boolean r0 = r1.equals(r0)
            if (r0 == 0) goto L_0x002c
            goto L_0x002d
        L_0x002c:
            r3 = 0
        L_0x002d:
            return r3
        L_0x002e:
            r20.hashCode()
            int r5 = r20.hashCode()
            java.lang.String r6 = "overflow"
            java.lang.String r7 = "borderLeftWidth"
            java.lang.String r8 = "borderLeftColor"
            java.lang.String r9 = "opacity"
            java.lang.String r10 = "borderBottomWidth"
            java.lang.String r11 = "borderBottomColor"
            java.lang.String r12 = "borderTopWidth"
            java.lang.String r13 = "borderTopColor"
            java.lang.String r14 = "borderRightWidth"
            java.lang.String r15 = "borderRightColor"
            java.lang.String r2 = "borderWidth"
            switch(r5) {
                case -1989576717: goto L_0x00d4;
                case -1971292586: goto L_0x00c9;
                case -1470826662: goto L_0x00be;
                case -1452542531: goto L_0x00b3;
                case -1308858324: goto L_0x00a8;
                case -1290574193: goto L_0x009d;
                case -1267206133: goto L_0x0092;
                case -242276144: goto L_0x0087;
                case -223992013: goto L_0x007b;
                case 529642498: goto L_0x006e;
                case 741115130: goto L_0x0061;
                case 1349188574: goto L_0x0052;
                default: goto L_0x004e;
            }
        L_0x004e:
            r16 = -1
            goto L_0x00de
        L_0x0052:
            java.lang.String r5 = "borderRadius"
            boolean r1 = r1.equals(r5)
            if (r1 != 0) goto L_0x005b
            goto L_0x004e
        L_0x005b:
            r1 = 11
            r16 = 11
            goto L_0x00de
        L_0x0061:
            boolean r1 = r1.equals(r2)
            if (r1 != 0) goto L_0x0068
            goto L_0x004e
        L_0x0068:
            r1 = 10
            r16 = 10
            goto L_0x00de
        L_0x006e:
            boolean r1 = r1.equals(r6)
            if (r1 != 0) goto L_0x0075
            goto L_0x004e
        L_0x0075:
            r1 = 9
            r16 = 9
            goto L_0x00de
        L_0x007b:
            boolean r1 = r1.equals(r7)
            if (r1 != 0) goto L_0x0082
            goto L_0x004e
        L_0x0082:
            r1 = 8
            r16 = 8
            goto L_0x00de
        L_0x0087:
            boolean r1 = r1.equals(r8)
            if (r1 != 0) goto L_0x008e
            goto L_0x004e
        L_0x008e:
            r1 = 7
            r16 = 7
            goto L_0x00de
        L_0x0092:
            boolean r1 = r1.equals(r9)
            if (r1 != 0) goto L_0x0099
            goto L_0x004e
        L_0x0099:
            r1 = 6
            r16 = 6
            goto L_0x00de
        L_0x009d:
            boolean r1 = r1.equals(r10)
            if (r1 != 0) goto L_0x00a4
            goto L_0x004e
        L_0x00a4:
            r1 = 5
            r16 = 5
            goto L_0x00de
        L_0x00a8:
            boolean r1 = r1.equals(r11)
            if (r1 != 0) goto L_0x00af
            goto L_0x004e
        L_0x00af:
            r1 = 4
            r16 = 4
            goto L_0x00de
        L_0x00b3:
            boolean r1 = r1.equals(r12)
            if (r1 != 0) goto L_0x00ba
            goto L_0x004e
        L_0x00ba:
            r1 = 3
            r16 = 3
            goto L_0x00de
        L_0x00be:
            boolean r1 = r1.equals(r13)
            if (r1 != 0) goto L_0x00c5
            goto L_0x004e
        L_0x00c5:
            r1 = 2
            r16 = 2
            goto L_0x00de
        L_0x00c9:
            boolean r1 = r1.equals(r14)
            if (r1 != 0) goto L_0x00d1
            goto L_0x004e
        L_0x00d1:
            r16 = 1
            goto L_0x00de
        L_0x00d4:
            boolean r1 = r1.equals(r15)
            if (r1 != 0) goto L_0x00dc
            goto L_0x004e
        L_0x00dc:
            r16 = 0
        L_0x00de:
            r17 = 0
            switch(r16) {
                case 0: goto L_0x01c7;
                case 1: goto L_0x01b6;
                case 2: goto L_0x01a5;
                case 3: goto L_0x0194;
                case 4: goto L_0x0183;
                case 5: goto L_0x0172;
                case 6: goto L_0x015f;
                case 7: goto L_0x014e;
                case 8: goto L_0x013d;
                case 9: goto L_0x0127;
                case 10: goto L_0x0116;
                case 11: goto L_0x00e4;
                default: goto L_0x00e3;
            }
        L_0x00e3:
            return r4
        L_0x00e4:
            java.lang.String r1 = "backgroundColor"
            boolean r5 = r0.hasKey(r1)
            if (r5 == 0) goto L_0x0100
            com.facebook.react.bridge.ReadableType r5 = r0.getType(r1)
            com.facebook.react.bridge.ReadableType r6 = com.facebook.react.bridge.ReadableType.Number
            if (r5 != r6) goto L_0x00fb
            int r1 = r0.getInt(r1)
            if (r1 == 0) goto L_0x00fb
            return r4
        L_0x00fb:
            com.facebook.react.bridge.ReadableType r1 = com.facebook.react.bridge.ReadableType.Null
            if (r5 == r1) goto L_0x0100
            return r4
        L_0x0100:
            boolean r1 = r0.hasKey(r2)
            if (r1 == 0) goto L_0x0115
            boolean r1 = r0.isNull(r2)
            if (r1 != 0) goto L_0x0115
            double r0 = r0.getDouble(r2)
            int r2 = (r0 > r17 ? 1 : (r0 == r17 ? 0 : -1))
            if (r2 == 0) goto L_0x0115
            return r4
        L_0x0115:
            return r3
        L_0x0116:
            boolean r1 = r0.isNull(r2)
            if (r1 != 0) goto L_0x0126
            double r0 = r0.getDouble(r2)
            int r2 = (r0 > r17 ? 1 : (r0 == r17 ? 0 : -1))
            if (r2 != 0) goto L_0x0125
            goto L_0x0126
        L_0x0125:
            r3 = 0
        L_0x0126:
            return r3
        L_0x0127:
            boolean r1 = r0.isNull(r6)
            if (r1 != 0) goto L_0x013c
            java.lang.String r0 = r0.getString(r6)
            java.lang.String r1 = "visible"
            boolean r0 = r1.equals(r0)
            if (r0 == 0) goto L_0x013b
            goto L_0x013c
        L_0x013b:
            r3 = 0
        L_0x013c:
            return r3
        L_0x013d:
            boolean r1 = r0.isNull(r7)
            if (r1 != 0) goto L_0x014d
            double r0 = r0.getDouble(r7)
            int r2 = (r0 > r17 ? 1 : (r0 == r17 ? 0 : -1))
            if (r2 != 0) goto L_0x014c
            goto L_0x014d
        L_0x014c:
            r3 = 0
        L_0x014d:
            return r3
        L_0x014e:
            com.facebook.react.bridge.ReadableType r1 = r0.getType(r8)
            com.facebook.react.bridge.ReadableType r2 = com.facebook.react.bridge.ReadableType.Number
            if (r1 != r2) goto L_0x015d
            int r0 = r0.getInt(r8)
            if (r0 != 0) goto L_0x015d
            goto L_0x015e
        L_0x015d:
            r3 = 0
        L_0x015e:
            return r3
        L_0x015f:
            boolean r1 = r0.isNull(r9)
            if (r1 != 0) goto L_0x0171
            double r0 = r0.getDouble(r9)
            r5 = 4607182418800017408(0x3ff0000000000000, double:1.0)
            int r2 = (r0 > r5 ? 1 : (r0 == r5 ? 0 : -1))
            if (r2 != 0) goto L_0x0170
            goto L_0x0171
        L_0x0170:
            r3 = 0
        L_0x0171:
            return r3
        L_0x0172:
            boolean r1 = r0.isNull(r10)
            if (r1 != 0) goto L_0x0182
            double r0 = r0.getDouble(r10)
            int r2 = (r0 > r17 ? 1 : (r0 == r17 ? 0 : -1))
            if (r2 != 0) goto L_0x0181
            goto L_0x0182
        L_0x0181:
            r3 = 0
        L_0x0182:
            return r3
        L_0x0183:
            com.facebook.react.bridge.ReadableType r1 = r0.getType(r11)
            com.facebook.react.bridge.ReadableType r2 = com.facebook.react.bridge.ReadableType.Number
            if (r1 != r2) goto L_0x0192
            int r0 = r0.getInt(r11)
            if (r0 != 0) goto L_0x0192
            goto L_0x0193
        L_0x0192:
            r3 = 0
        L_0x0193:
            return r3
        L_0x0194:
            boolean r1 = r0.isNull(r12)
            if (r1 != 0) goto L_0x01a4
            double r0 = r0.getDouble(r12)
            int r2 = (r0 > r17 ? 1 : (r0 == r17 ? 0 : -1))
            if (r2 != 0) goto L_0x01a3
            goto L_0x01a4
        L_0x01a3:
            r3 = 0
        L_0x01a4:
            return r3
        L_0x01a5:
            com.facebook.react.bridge.ReadableType r1 = r0.getType(r13)
            com.facebook.react.bridge.ReadableType r2 = com.facebook.react.bridge.ReadableType.Number
            if (r1 != r2) goto L_0x01b4
            int r0 = r0.getInt(r13)
            if (r0 != 0) goto L_0x01b4
            goto L_0x01b5
        L_0x01b4:
            r3 = 0
        L_0x01b5:
            return r3
        L_0x01b6:
            boolean r1 = r0.isNull(r14)
            if (r1 != 0) goto L_0x01c6
            double r0 = r0.getDouble(r14)
            int r2 = (r0 > r17 ? 1 : (r0 == r17 ? 0 : -1))
            if (r2 != 0) goto L_0x01c5
            goto L_0x01c6
        L_0x01c5:
            r3 = 0
        L_0x01c6:
            return r3
        L_0x01c7:
            com.facebook.react.bridge.ReadableType r1 = r0.getType(r15)
            com.facebook.react.bridge.ReadableType r2 = com.facebook.react.bridge.ReadableType.Number
            if (r1 != r2) goto L_0x01d6
            int r0 = r0.getInt(r15)
            if (r0 != 0) goto L_0x01d6
            goto L_0x01d7
        L_0x01d6:
            r3 = 0
        L_0x01d7:
            return r3
        */
        throw new UnsupportedOperationException("Method not decompiled: com.facebook.react.uimanager.ViewProps.isLayoutOnly(com.facebook.react.bridge.ReadableMap, java.lang.String):boolean");
    }
}
